# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`vault`](#vault): Issue and renew PKI certificates from Hashicorp Vault

### Functions

* [`vault_cert`](#vault_cert): Obtain a host certificate from a Vault PKI secrets engine
* [`vault_hash`](#vault_hash): Return a hash from a Vault key/value secrets engine path
* [`vault_hiera_hash`](#vault_hiera_hash): Custom hiera back-end for Hashicorp Vault key/value secrets engine
* [`vault_key`](#vault_key): Return the value from a Vault key/value secrets engine from a given path and key

## Classes

### `vault`

Issue and renew PKI certificates from Hashicorp Vault

#### Examples

##### Issue a host certificate from a Vault server with PKI secrets engine

```puppet
class { 'vault':
  vault_uri  => 'https://vault.example.com:8200/v1/pki/issue/example-com',
  auth_path  => 'puppet-pki',
}
```

#### Parameters

The following parameters are available in the `vault` class.

##### `vault_uri`

Data type: `String`

The complete URL of the the Hashicorp Vault certificate issuing role API endpoint

##### `auth_path`

Data type: `String`

The Vault path of the authentication provider used by Puppet certificates

##### `days_before_renewal`

Data type: `Integer[1, 30]`

The number of days before expiration where the host certificate will be re-issued

Default value: `3`

##### `cert_data`

Data type: `Hash`

A hash of values to be submitted with the certificate request.  The hash contents should
adhere to the keys/values supported/permitted by the PKI role and policy.  Basic default values are
defined in module hiera.

Default value: `{}`

## Functions

### `vault_cert`

Type: Ruby 4.x API

Obtain a host certificate from a Vault PKI secrets engine

#### `vault_cert(String $vault_uri, String $auth_path, Hash $data, Optional[Integer] $timeout)`

The vault_cert function.

Returns: `Hash` The returned hash contains the certificate, private key, and supporting data

##### `vault_uri`

Data type: `String`

The complete API path to a Vault PKI role for issuing certificates.

##### `auth_path`

Data type: `String`

The Vault mount path of the "cert" authentication type used with Puppet certificates.

##### `data`

Data type: `Hash`

A hash of values to be submitted with a certificate request.  The hash contents
must adhere to the constructs of the Vault PKI role and policy being used at the 'vault_uri' endpoint.

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for Vault connections.  Default is 5.

### `vault_hash`

Type: Ruby 4.x API

Return a hash from a Vault key/value secrets engine path

#### `vault_hash(String $vault_uri, String $auth_path, Optional[String] $version, Optional[Integer] $timeout)`

The vault_hash function.

Returns: `Hash` Contains all the key/value pairs from the given path.

##### `vault_uri`

Data type: `String`

The full URI to the Vault API endpoint for a key/value secrets engine path.

##### `auth_path`

Data type: `String`

The Vault mount path of the 'cert' authentication type used with Puppet certificates.

##### `version`

Data type: `Optional[String]`

Set this value to 'v2' to use version 2 of the Vault key/value secrets engine.

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for Vault connections.

### `vault_hiera_hash`

Type: Ruby 4.x API

Custom hiera back-end for Hashicorp Vault key/value secrets engine

#### `vault_hiera_hash(Hash $options, Puppet::LookupContext $context)`

The vault_hiera_hash function.

Returns: `Hash` All key/value pairs from the given Vault path will be returned to hiera

##### `options`

Data type: `Hash`

Hash containing:

##### `context`

Data type: `Puppet::LookupContext`

Unused. The function will raise an error if Vault lookup fails

### `vault_key`

Type: Ruby 4.x API

Return the value from a Vault key/value secrets engine from a given path and key

#### `vault_key(String $vault_uri, String $auth_path, String $key, Optional[String] $version, Optional[Integer] $timeout)`

The vault_key function.

Returns: `String` The value of the secret from the @vault_uri and @key

##### `vault_uri`

Data type: `String`

The complete API path to a Vault key/value secret

##### `auth_path`

Data type: `String`

The Vault mount path of the "cert" authentication type used with Puppet certificates.

##### `key`

Data type: `String`

The name of a specific secret at the given 'vault_uri'

##### `version`

Data type: `Optional[String]`

Set this value to 'v2' to use version 2 of the Vault key/value secrets engine

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for a response from Vault

